@@ -1,10 +1,10 @@
 from uptrain.core.classes import Framework
 from uptrain.core.classes.signals import Signal
-from uptrain.core.classes.anomalies import CustomAnomaly
+from uptrain.core.classes.monitors import CustomMonitor
 from uptrain.constants import (
     ModelSignal,
     AnnotationMethod,
-    Anomaly,
+    Monitor,
     DataDriftAlgo,
     BiasAlgo,
     MeasurableType,
