@@ -5,9 +5,8 @@ from .output_feature import OutputFeatureMeasurable
 from .feature import FeatureMeasurable
 from .condition import ConditionMeasurable
 from .custom import CustomMeasurable
-from .accuracy import AccuracyMeasurable
+from .accuracy import AccuracyMeasurable, MAEMeasurable, MAPEMeasurable
 from .scalar_from_embedding import ScalarFromEmbeddingMeasurable
 from .distance import DistanceMeasurable
 from .reccomendation_hit_rate import RecHitRateMeasurable
-
 from .measurable_resolver import MeasurableResolver
