@@ -1,8 +1,35 @@
+from typing import Any, Dict
+
 from uptrain.core.classes.measurables import Measurable, FeatureMeasurable
 
 
 class ConditionMeasurable(Measurable):
-    def __init__(self, framework, underlying, condition) -> None:
+    """Class that computes a boolean condition on a measurable feature."""
+
+    def __init__(
+        self, framework, underlying: Dict[str, Any], condition: Dict[str, Any]
+    ) -> None:
+        """Constructor for ConditionMeasurable class.
+
+        Parameters
+        ----------
+        framework
+            UpTrain Framework object
+        underlying
+            A dictionary containing the feature_name to apply the condition on and
+            the dictn_type (whether to apply on inputs or outputs).
+            dictn_type should be "inputs" for applying InputFeatureMeasurable
+            dictn_type should be "outputs" for applying OutputFeatureMeasurable
+        condition
+            A dictionary containing either "formulae" or "func" as key.
+            If "formulae" is provided:
+                - it must be a boolean operator from the following list of operators:
+                    ["<", "<=", ">", ">=", "==", "le", "leq", "ge", "geq", "eq"]
+                - it must contain "threshold" as key which provides the value to perform
+                  the boolean condition against.
+            If "func" is provided, it should map to a callback that accepts a single
+            argument and returns a boolean value.
+        """
         super().__init__(framework)
         self.underlying = underlying
         self.condition = condition
@@ -31,16 +58,10 @@ class ConditionMeasurable(Measurable):
             )
         self.condition_func = condition_func
 
-    def _compute(self, inputs=None, outputs=None, gts=None, extra=None) -> any:
+    def _compute(self, inputs=None, outputs=None, gts=None, extra=None) -> Any:
         return self.condition_func(
             self.feature._compute(inputs=inputs, outputs=outputs, gts=gts, extra=extra)
         )
 
-    def col_name(self):
-        return (
-            "Condition("
-            + self.feature.col_name()
-            + ","
-            + str(self.condition)
-            + ")"
-        )
+    def col_name(self) -> str:
+        return f"Condition({self.feature.col_name()}, {str(self.condition)})"
