@@ -1,3 +1,5 @@
+from typing import Any
+
 from uptrain.core.classes.measurables import (
     Measurable,
     InputFeatureMeasurable,
@@ -6,7 +8,19 @@ from uptrain.core.classes.measurables import (
 
 
 class FeatureMeasurable(Measurable):
-    def __init__(self, framework, feature_name, dictn_type) -> None:
+    """Class that returns a feature as a result of computation."""
+
+    def __init__(self, framework, feature_name, dictn_type: str) -> None:
+        """Constructor for FeatureMeasurable class.
+        
+        Parameters
+        ----------
+        feature_name
+            Name of the feature that is to be measured/evaluated
+        dictn_type
+            Must be "inputs" or "outputs" depending on which feature to
+            measure/evaluate
+        """
         super().__init__(framework)
         self.feature_name = feature_name
         self.dictn_type = dictn_type
@@ -19,12 +33,12 @@ class FeatureMeasurable(Measurable):
                 "Helper Measurable not defined for dictionary type %s" % self.dictn_type
             )
 
-    def _compute(self, inputs=None, outputs=None, gts=None, extra=None) -> any:
+    def _compute(self, inputs=None, outputs=None, gts=None, extra=None) -> Any:
         return self.helper._compute(
             inputs=inputs, outputs=outputs, gts=gts, extra=extra
         )
 
-    def col_name(self):
+    def col_name(self) -> str:
         return self.helper.col_name()
 
     # TODO: Decommission and find a generic way
