@@ -4,6 +4,8 @@ from uptrain.core.classes.measurables import (
     ConditionMeasurable,
     CustomMeasurable,
     AccuracyMeasurable,
+    MAEMeasurable,
+    MAPEMeasurable,
     ScalarFromEmbeddingMeasurable,
     DistanceMeasurable,
     RecHitRateMeasurable,
@@ -12,17 +14,17 @@ from uptrain.constants import MeasurableType
 
 
 class MeasurableResolver:
+    """Class that resolves a measurable key to a measurable class instance."""
+
     def __init__(self, args) -> None:
         super().__init__()
         self._args = args
 
-    def has_valid_resolve_args(self):
+    def has_valid_resolve_args(self) -> bool:
         if self._args is None:
             return False
-
         if len(self._args) == 0:
             return False
-
         return True
 
     def resolve(self, framework) -> Measurable:
@@ -39,6 +41,10 @@ class MeasurableResolver:
             return CustomMeasurable(framework, resolve_args)
         elif measurable_type == MeasurableType.ACCURACY:
             return AccuracyMeasurable(framework)
+        elif measurable_type == MeasurableType.MAE:
+            return MAEMeasurable(framework)
+        elif measurable_type == MeasurableType.MAPE:
+            return MAPEMeasurable(framework)
         elif measurable_type == MeasurableType.CONDITION_ON_INPUT:
             return ConditionMeasurable(
                 framework,
