@@ -1,3 +1,5 @@
+from typing import Any
+
 from uptrain.core.classes.measurables import (
     Measurable,
     InputFeatureMeasurable,
@@ -5,6 +7,8 @@ from uptrain.core.classes.measurables import (
 
 
 class ScalarFromEmbeddingMeasurable(Measurable):
+    """Class that extracts a scalar from a measurable embedding."""
+
     def __init__(self, framework, idx, extract_from_args) -> None:
         super().__init__(framework)
         self.idx = idx
@@ -12,18 +16,13 @@ class ScalarFromEmbeddingMeasurable(Measurable):
             framework, extract_from_args["feature_name"]
         )
 
-    def _compute(self, inputs=None, outputs=None, gts=None, extra=None) -> any:
+    def _compute(self, inputs=None, outputs=None, gts=None, extra=None) -> Any:
         return self.extract_from._compute(
             inputs=inputs, outputs=outputs, gts=gts, extra=extra
         )[self.idx]
 
-    def col_name(self):
-        return (
-            "Scalar [Index:"
-            + str(self.idx)
-            + "] from Embedding: "
-            + str(self.extract_from.col_name())
-        )
+    def col_name(self) -> str:
+        return f"Scalar [Index: {str(self.idx)}] from Embedding: {str(self.extract_from.col_name())}"
 
     # TODO: Decommission and find a generic way
     def extract_val_from_training_data(self, x):
